@@ -1,6 +1,8 @@
 import difflib
 import re
-from typing import List
+from typing import Iterable
+
+from metrics_layer.core.exceptions import QueryError
 
 NAME_REGEX = re.compile(r"([A-Za-z0-9\_]+)")
 
@@ -32,6 +34,13 @@ class MetricsLayerBase:
             "the naming conventions (only letters, numbers, or underscores)"
         )
 
+    @staticmethod
+    def _raise_query_error_from_cte(field_name: str):
+        raise QueryError(
+            f"Field {field_name} is not present in either source query, so it"
+            " cannot be applied as a filter. Please add it to one of the source queries."
+        )
+
     @staticmethod
     def line_col(element):
         line = getattr(getattr(element, "lc", None), "line", None)
@@ -40,7 +49,7 @@ class MetricsLayerBase:
 
     @staticmethod
     def invalid_property_error(
-        definition: dict, valid_properties: List[str], entity_name: str, name: str, error_func: callable
+        definition: dict, valid_properties: Iterable[str], entity_name: str, name: str, error_func: callable
     ):
         errors = []
         for key in definition:
@@ -70,7 +79,7 @@ class MetricsLayerBase:
         return explore_name, view_name, name
 
     @staticmethod
-    def propose_property(invalid_property_name: str, valid_properties: List[str]) -> str:
+    def propose_property(invalid_property_name: str, valid_properties: Iterable[str]) -> str:
         closest_match = difflib.get_close_matches(invalid_property_name, valid_properties, n=1)
         if closest_match:
             return closest_match[0]
